@@ -154,3 +154,19 @@ pub struct AsStruct;
 /// Additional argument for a function that returns a C++ object as a pointer
 /// enclosed in a CppBox.
 pub struct AsBox;
+
+
+pub mod new_uninitialized {
+
+  /// A trait for types that can be created with
+  /// uninitialized internal buffer.
+  ///
+  /// This trait should not be used directly.
+  /// It's only useful for the code automatically generated
+  /// by cpp_to_rust.
+  pub trait NewUninitialized {
+    /// Creates new object with
+    /// uninitialized internal buffer.
+    unsafe fn new_uninitialized() -> Self;
+  }
+}
